sqlobject.tests.test_csvexport module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_csvexport module

class `sqlobject.tests.test_csvexport.` `ComplexCSV`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `age`
  `csvColumnOrder` = ['name', 'fname', 'lname', 'age']
  `extraCSVColumns` = [('name', 'Full Name'), 'initials']
  property `fname`
  property `initials`
  `j` = complex_cs_v
  property `lname`
  property `name`
  `q` = complex_cs_v
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_csvexport.ComplexCSV`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'complex_cs_v'

class `sqlobject.tests.test_csvexport.` `SimpleCSV`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `address`
  property `hidden`
  `j` = simple_cs_v
  property `name`
  `q` = simple_cs_v
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_csvexport.SimpleCSV`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'simple_cs_v'

`sqlobject.tests.test_csvexport.` `assert_export`(result, *args, **kw)

`sqlobject.tests.test_csvexport.` `test_complex`()

`sqlobject.tests.test_csvexport.` `test_simple`()

`sqlobject.tests.test_csvexport.` `test_zip`()